==> fred-prequel-0.1.0.tar.gz: fred-prequel-0.1.0/prequel/tests/test_info.py <==
from typing import Dict, List
from unittest import IsolatedAsyncioTestCase
from unittest.mock import sentinel

from aioitertools import iter as aiter
from fred_api.public_request.common_types_pb2 import (
    ObjectType as ObjectTypeMsg,
    PublicRequestDoesNotExist as PublicRequestDoesNotExistMsg,
    PublicRequestType as PublicRequestTypeMsg,
)
from fred_api.public_request.service_public_request_info_grpc_pb2 import (
    GetReply as GetReplyMsg,
    GetRequest as GetRequestMsg,
    GetTypesReply as GetTypesReplyMsg,
    ListReply as ListReplyMsg,
    ListRequest as ListRequestMsg,
)
from frgal.utils import AsyncTestClientMixin, make_awaitable
from google.protobuf import empty_pb2

from prequel.common import PublicRequest
from prequel.decoder import PublicRequestDecoder
from prequel.exceptions import PublicRequestDoesNotExist
from prequel.info import PublicRequestInfoClient

from .test_decoder import PublicRequestMsgFactory


class TestPublicRequestInfoClient(AsyncTestClientMixin, PublicRequestInfoClient):
    """Test client for PublicRequestInfoClient."""


class PublicRequestInfoTest(IsolatedAsyncioTestCase):
    def _make_get_types(self, data: Dict[str, bool]) -> GetTypesReplyMsg:
        """Prepare reply for 'get_types' method."""
        result = GetTypesReplyMsg()
        for name, is_resolvable in data.items():
            result.data.types.append(PublicRequestTypeMsg(name=name, is_resolvable=is_resolvable))
        return result

    async def _test_case_get_types(self, data: Dict[str, bool]) -> None:
        """Helper for testing 'get_types' method."""
        public_request_types = self._make_get_types(data)
        self.client.mock.return_value = make_awaitable(public_request_types)
        response = await self.client.get_types()
        self.assertEqual(response, data)

    def _make_list(self, chunk_sizes: List[int]) -> List[ListReplyMsg]:
        """Prepare reply for 'list' method."""
        result: List[ListReplyMsg] = []
        # messages sequentially numbered and divided into chunks
        id = 1
        for chunk_size in chunk_sizes:  # chunk_sizes must not be empty
            message = ListReplyMsg()
            message.data.public_requests.extend(
                [PublicRequestMsgFactory.make(id=id + i) for i in range(chunk_size)]
            )
            result.append(message)
            id += chunk_size
        return result

    async def _test_case_list(
        self, obj_type: str, obj_value: str, chunk_sizes: List[int]
    ) -> List[PublicRequest]:
        """Helper for testing 'list' method."""
        list_reply = self._make_list(chunk_sizes)
        self.client.mock.return_value = aiter(list_reply)
        response = await self.client.list(obj_type, obj_value)
        # test sequence of numeric identifiers in received public requests
        self.assertEqual(
            [i + 1 for i in range(sum(chunk_sizes))], [i.numeric_id for i in response]
        )
        return response

    def setUp(self):
        self.client = TestPublicRequestInfoClient(netloc=sentinel.netloc)
        self.decoder = PublicRequestDecoder()

    async def test_get_types_none(self):
        await self._test_case_get_types({})
        # check call arguments
        self.client.mock.assert_called_once_with(
            empty_pb2.Empty(),
            method="/Fred.PublicRequest.Api.PublicRequestInfo/get_types",
            timeout=None,
        )

    async def test_get_types_many(self):
        data = {
            "AuthInfo": True,
            "LockObject": True,
            "UnlockObject": True,
            "GetDetails": True,
        }
        await self._test_case_get_types(data)

    async def test_get_types_empty_name(self):
        await self._test_case_get_types({"": False})

    async def test_list_empty(self):
        obj_type = "domain"
        obj_value = "example.org"
        await self._test_case_list(obj_type, obj_value, [0])
        # check call arguments
        list_request = ListRequestMsg()
        list_request.object_id.type = ObjectTypeMsg.Enum.Value(obj_type)
        list_request.object_id.value = obj_value
        self.client.mock.assert_called_once_with(
            list_request,
            method="/Fred.PublicRequest.Api.PublicRequestInfo/list",
            timeout=None,
        )

    async def test_list_one_item(self):
        # response stream of single item in single chunk
        list_reply = await self._test_case_list("domain", "example.org", [1])
        self.assertEqual(len(list_reply), 1)
        # verify public request message in response
        # (default id = 1 so the comparison should pass)
        self.assertEqual(list_reply[0], PublicRequestMsgFactory.default_src())

    async def test_list_many_items(self):
        # response stream of several chunks
        await self._test_case_list("domain", "example.org", [3, 2, 1, 5])

    async def test_list_empty_chunks(self):
        # empty chunks within response stream
        await self._test_case_list("domain", "example.org", [2, 0, 0, 4, 0])

    async def test_get_found(self):
        id = "ID-1"
        get_reply = GetReplyMsg()
        get_reply.data.CopyFrom(PublicRequestMsgFactory.make())
        self.client.mock.return_value = make_awaitable(get_reply)
        public_request = await self.client.get(id)
        self.assertEqual(public_request, PublicRequestMsgFactory.default_src())
        # check call arguments
        get_request = GetRequestMsg()
        get_request.public_request_id.value = id
        self.client.mock.assert_called_once_with(
            get_request,
            method="/Fred.PublicRequest.Api.PublicRequestInfo/get",
            timeout=None,
        )

    async def test_get_not_found(self):
        get_reply = GetReplyMsg()
        get_reply.exception.public_request_does_not_exist.CopyFrom(PublicRequestDoesNotExistMsg())
        self.client.mock.return_value = make_awaitable(get_reply)
        with self.assertRaises(PublicRequestDoesNotExist):
            await self.client.get("ID-1")

==> fred-prequel-0.2.2.tar.gz: fred-prequel-0.2.2/prequel/tests/test_info.py <==
from typing import Dict, List
from unittest import IsolatedAsyncioTestCase
from unittest.mock import sentinel

from aioitertools import iter as aiter
from fred_api.public_request.common_types_pb2 import (
    PublicRequestDoesNotExist as PublicRequestDoesNotExistMsg,
    PublicRequestType as PublicRequestTypeMsg,
    RegistryObjectType as RegistryObjectTypeMsg,
)
from fred_api.public_request.service_public_request_info_grpc_pb2 import (
    GetReply as GetReplyMsg,
    GetRequest as GetRequestMsg,
    GetTypesReply as GetTypesReplyMsg,
    ListReply as ListReplyMsg,
    ListRequest as ListRequestMsg,
)
from frgal.utils import AsyncTestClientMixin, make_awaitable
from google.protobuf import empty_pb2

from prequel.common import PublicRequest, PublicRequestId
from prequel.decoder import PublicRequestDecoder
from prequel.exceptions import PublicRequestDoesNotExist
from prequel.info import PublicRequestInfoClient

from .test_decoder import PublicRequestMsgFactory


class TestPublicRequestInfoClient(AsyncTestClientMixin, PublicRequestInfoClient):
    """Test client for PublicRequestInfoClient."""


class PublicRequestInfoTest(IsolatedAsyncioTestCase):
    def _make_get_types(self, data: Dict[str, bool]) -> GetTypesReplyMsg:
        """Prepare reply for 'get_types' method."""
        result = GetTypesReplyMsg()
        for name, is_resolvable in data.items():
            result.data.types.append(PublicRequestTypeMsg(name=name, is_resolvable=is_resolvable))
        return result

    async def _test_case_get_types(self, data: Dict[str, bool]) -> None:
        """Helper for testing 'get_types' method."""
        public_request_types = self._make_get_types(data)
        self.client.mock.return_value = make_awaitable(public_request_types)
        response = await self.client.get_types()
        self.assertEqual(response, data)

    def _make_list(self, chunk_sizes: List[int]) -> List[ListReplyMsg]:
        """Prepare reply for 'list' method."""
        result: List[ListReplyMsg] = []
        # messages sequentially numbered and divided into chunks
        id = 1
        for chunk_size in chunk_sizes:  # chunk_sizes must not be empty
            message = ListReplyMsg()
            message.data.public_requests.extend(
                [PublicRequestMsgFactory.make(id=id + i) for i in range(chunk_size)]
            )
            result.append(message)
            id += chunk_size
        return result

    async def _test_case_list(
        self, ref_type: str, ref_value: str, chunk_sizes: List[int]
    ) -> List[PublicRequest]:
        """Helper for testing 'list' method."""
        list_reply = self._make_list(chunk_sizes)
        self.client.mock.return_value = aiter(list_reply)
        response = await self.client.list(ref_type, ref_value)
        # test sequence of numeric identifiers in received public requests
        self.assertEqual(
            [i + 1 for i in range(sum(chunk_sizes))], [i.numeric_id for i in response]
        )
        return response

    def setUp(self):
        self.client = TestPublicRequestInfoClient(netloc=sentinel.netloc)
        self.decoder = PublicRequestDecoder()

    async def test_get_types_none(self):
        await self._test_case_get_types({})
        # check call arguments
        self.client.mock.assert_called_once_with(
            empty_pb2.Empty(),
            method="/Fred.PublicRequest.Api.PublicRequestInfo/get_types",
            timeout=None,
        )

    async def test_get_types_many(self):
        data = {
            "AuthInfo": True,
            "LockObject": True,
            "UnlockObject": True,
            "GetDetails": True,
        }
        await self._test_case_get_types(data)

    async def test_get_types_empty_name(self):
        await self._test_case_get_types({"": False})

    async def test_list_empty(self):
        ref_type = "domain"
        ref_value = "012-3454-6789"
        await self._test_case_list(ref_type, ref_value, [0])
        # check call arguments
        list_request = ListRequestMsg()
        list_request.registry_object_reference.type = RegistryObjectTypeMsg.Enum.Value(ref_type)
        list_request.registry_object_reference.value = ref_value
        self.client.mock.assert_called_once_with(
            list_request,
            method="/Fred.PublicRequest.Api.PublicRequestInfo/list",
            timeout=None,
        )

    async def test_list_one_item(self):
        # response stream of single item in single chunk
        list_reply = await self._test_case_list("domain", "012-345-6789", [1])
        self.assertEqual(len(list_reply), 1)
        # verify public request message in response
        # (default id = 1 so the comparison should pass)
        self.assertEqual(list_reply[0], PublicRequestMsgFactory.default_src())

    async def test_list_many_items(self):
        # response stream of several chunks
        await self._test_case_list("domain", "012-345-6789", [3, 2, 1, 5])

    async def test_list_empty_chunks(self):
        # empty chunks within response stream
        await self._test_case_list("domain", "012-345-6789", [2, 0, 0, 4, 0])

    async def test_get_found(self):
        id = PublicRequestId("ID-1")
        get_reply = GetReplyMsg()
        get_reply.data.CopyFrom(PublicRequestMsgFactory.make())
        self.client.mock.return_value = make_awaitable(get_reply)
        public_request = await self.client.get(id)
        self.assertEqual(public_request, PublicRequestMsgFactory.default_src())
        # check call arguments
        get_request = GetRequestMsg()
        get_request.public_request_id.value = id
        self.client.mock.assert_called_once_with(
            get_request,
            method="/Fred.PublicRequest.Api.PublicRequestInfo/get",
            timeout=None,
        )

    async def test_get_not_found(self):
        get_reply = GetReplyMsg()
        get_reply.exception.public_request_does_not_exist.CopyFrom(PublicRequestDoesNotExistMsg())
        self.client.mock.return_value = make_awaitable(get_reply)
        with self.assertRaises(PublicRequestDoesNotExist):
            await self.client.get(PublicRequestId("ID-1"))
